@@ -11,15 +11,17 @@
 
 var session = require('express-session');
 var logger = require('winston');
+var logger = require('fs');
 var RDBStore = require('./../datasource/rethinkdb-session')(session);
-
+const config = require(process.cwd() + '/config/config');
+var dbId=config.appId.replace(/-/g,"");
 
 module.exports = function (app, db) {
-
+    var cert = fs.readFileSync(process.cwd() + '/ssl/server.key');  // get private key
 
     var rdbStore = new RDBStore({
         connection: db,
-        db: 'oauth',
+        db: dbId,
         table: 'session',
         sessionTimeout: 5 * 60 * 1000,
         flushInterval: 5 * 61 * 1000,
@@ -32,7 +34,7 @@ module.exports = function (app, db) {
         resave: false,
         saveUninitialized: true,
         key: 'sid',
-        secret: 'my5uperSEC537(key)!',
+        secret: cert,
       //  cookie: { maxAge: 5 * 60 * 1000 },
         store: rdbStore
     }));
