@@ -22,15 +22,20 @@ var loadSchema = function (models, callback) {
         logger.info("Load Data Model :: " + model.replace(work_dir, ""));
         try {
             fs.readFile(model, 'utf8', function (err, data) {
-                if (err) next(err);
-                obj = JSON.parse(data);
-                ajv.addSchema(obj, obj.name);
-                next();
+                if (err) {
+                    logger.error(err);
+                    next();
+                } else {
+                    obj = JSON.parse(data);
+                    ajv.addSchema(obj, obj.name);
+                    next();
+                }
+
             });
         }
         catch (err) {
             logger.error(err);
-            next(err);
+            next();
         }
 
     }, function (err) {
